# just-module
Basic classes for Just-DNA-Seq modules

## Installation

You can use conda or micromamba to install the environment.

```bash
micromamba env create -f environment.yaml
```

Activate the environment:
```bash
micromamba activate just-dna-module
```

The library do not have executables but is just used inside Just-DNA-Seq module providing base classes for modules and their utils.
